@@ -91,7 +91,7 @@ class Config:
             核素列表名
         Returns
         -------
-        list[str]
+        list[str] or str
         """
         return self.conf.get("nuclide_list").get(nuclide_name, None)
 
